(function (d3) {
  // Load data
  d3.csv(
    'https://gist.githubusercontent.com/YaminiSreejith/9ce001ba329265e9b3502991d403575b/raw/4c1f201d34aa4265bf1b115eecae98cb6dae47b2/gistfile1.csv',
  )
    .then(function (data) {
      // Log the data before conversion
      console.log('Data before conversion:', data);

      // Convert string values to numbers
      data.forEach(function (d) {
        d['Total Sales'] = +d['Total Sales'].replace(
          ',',
          '',
        );
      });

      // Log the data after conversion
      console.log('Data after conversion:', data);

      // Define SVG dimensions
      var svgWidth = 800;
      var svgHeight = 500;

      // Define margins
      var margin = {
        top: 50,
        right: 50,
        bottom: 50,
        left: 50,
      };

      var width = svgWidth - margin.left - margin.right;
      var height = svgHeight - margin.top - margin.bottom;

      // Append SVG to the body
      var svg = d3
        .select('#line-chart')
        .attr('width', svgWidth)
        .attr('height', svgHeight);

      // Append group element to SVG
      var g = svg
        .append('g')
        .attr(
          'transform',
          'translate(' +
            margin.left +
            ',' +
            margin.top +
            ')',
        );

      // Define scales
      var xScale = d3
        .scaleBand()
        .domain(
          data.map(function (d) {
            return d['Product Category'];
          }),
        )
        .range([0, width])
        .padding(0.1);

      var yScale = d3
        .scaleLinear()
        .domain([
          0,
          d3.max(data, function (d) {
            return d['Total Sales'];
          }),
        ])
        .range([height, 0]);

      // Create and append the x-axis
      g.append('g')
        .attr('transform', 'translate(0,' + height + ')')
        .call(d3.axisBottom(xScale))
        .append('text')
        .attr('y', 40)
        .attr('x', width / 2)
        .attr('text-anchor', 'middle')
        .attr('fill', 'black')
        .text('Product Category');

      // Create and append the y-axis
      g.append('g')
        .call(d3.axisLeft(yScale))
        .append('text')
        .attr('transform', 'rotate(-90)')
        .attr('y', -40)
        .attr('x', -height / 2)
        .attr('dy', '0.71em')
        .attr('text-anchor', 'middle')
        .attr('fill', 'black')
        .text('Total Sales');

      // Define the line
      var line = d3
        .line()
        .x(function (d) {
          return (
            xScale(d['Product Category']) +
            xScale.bandwidth() / 2
          );
        })
        .y(function (d) {
          return yScale(d['Total Sales']);
        });

      // Append the line path to the chart
      g.append('path')
        .datum(data)
        .attr('fill', 'none')
        .attr('stroke', 'steelblue')
        .attr('stroke-width', 2)
        .attr('d', line);
    })
    .catch(function (error) {
      // Log if there's an error loading data
      console.log('Error loading data:', error);
    });

  console.log('Script ended');
  // Log to check if the script execution ends
})(d3);
